#!/bin/sh

echo 2 > /proc/sys/vm/overcommit_memory
echo 100 > /proc/sys/vm/overcommit_ratio

echo "Start firmware upgrading"
echo "Start firmware upgrading" > /dev/console


#some validation
if [ -f "./fmw_board_type" ]; then
    cur_board=`factory board | sed y/abcdefghijklmnopqrstuvwxyz/ABCDEFGHIJKLMNOPQRSTUVWXYZ/`
    case "$cur_board"  in
        WB-2P-LR2)            board_type="WB-2P-LR2";;
        WB-2P-LR5)            board_type="WB-2P-LR5";;
        "WB-2P-LR5:REV.B")    board_type="WB-2P-LR5";;
        "WB-2P-LR5:REV.B6")   board_type="WB-2P-LR5";;
        "WB-2P-LR5:REV.C")    board_type="WB-2P-LR5";;
    esac

    if [ -z "$board_type" ]; then
        echo "UPGRADE FAIL: wrong factory settings"
        exit 1;
    fi

    fmw_type=`cat ./fmw_board_type`
    if [ "$fmw_type" != "$board_type" ]; then
        echo "UPGRADE FAIL: firmware for $fmw_type but board is $cur_board"
        exit 1;
    fi
fi

md5_cur=`busybox md5sum ./linux.bin | cut -d' ' -f 1`
md5_img=`cat md5_linux`
if [ "$md5_cur" != "$md5_img" ]; then
    echo "UPGRADE FAIL: Incorrect CRC";
    exit 1;
fi

killall igmpproxy udpxy

if [ -f /tmp/fw/utils/upgrade-bin ]; then
    FW_PATH="/tmp/fw"
else
    if [ -f /tmp/auto_fw_upgrade/utils/upgrade-bin ]; then
	FW_PATH="/tmp/auto_fw_upgrade"
    else
    if [ -f /tmp/dhcp_fw_upgrade/utils/upgrade-bin ]; then
        FW_PATH="/tmp/dhcp_fw_upgrade"
    else
        FW_PATH="/tmp/fw_tr069"
    fi
    fi
fi


chmod 777 $FW_PATH/upgrade-bin

cur_major=$(cat /version|cut -d'.' -f 1)
cur_minor=$(cat /version|cut -d'.' -f 2)

echo "Upgrade firmware started"
echo "Upgrade firmware started" > /dev/console
$FW_PATH/utils/upgrade-bin ./linux.bin &> /dev/console
RETVAL=$?

if [ "$RETVAL" != "0" ]; then
    if [ "$RETVAL" = "254" ]; then
	echo "UPGRADE FAIL: upgrade process is already in progress" > /dev/console;
	echo "UPGRADE FAIL: upgrade process is already in progress";
	exit 2;
    fi
    echo "UPGRADE FAIL: Error at read/write operation" > /dev/console;
    echo "UPGRADE FAIL: Error at read/write operation";
    exit 1;
fi

if [ -f /proc/bootbank ]; then
    BANK=$(cat /proc/bootbank)
    if [ -f $FW_PATH/version ]; then
        NEW_VERSION=$(cat $FW_PATH/version)
        if [ "$BANK" = "1" ]; then
            fwctl set 2 "$NEW_VERSION"
        else
            if [ "$BANK" = "2" ]; then
                fwctl set 1 "$NEW_VERSION"
            fi
        fi
    fi
fi

if [ -e "$FW_PATH/defaults" ];then
    echo "UPGRADE : update def.yaml" > /dev/console;
    echo "UPGRADE : update def.yaml";
    cd $FW_PATH
    cat /proc/mtd | grep "mtd2" > /dev/null
    if [ $? == 0 ]; then
        tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml
    else
        tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml_old
    fi
#    tar -c defaults | gzip | $FW_PATH/utils/save_def_yaml
    cd -
fi

echo "UPGRADE SUCCESSFULL" > /dev/console
echo "UPGRADE SUCCESSFULL"
exit 0;
